@@ -2,7 +2,6 @@
 
 This is the entrypoint for the `phi ws` commands
 """
-
 from typing import Optional, cast
 
 import typer
@@ -24,9 +23,9 @@ from phiterm.workspace.ws_enums import (
 
 ws_app = typer.Typer(
     name="ws",
-    short_help="Commands to manage your workspaces",
+    short_help="Manage workspaces",
     help="""\b
-Use `phi ws <command>` to create, setup or delete your phidata workspace.
+Use `phi ws <command>` to create, setup or update your workspace.
 Run `phi ws <command> --help` for more info.
 """,
     no_args_is_help=True,
@@ -37,16 +36,16 @@ Run `phi ws <command> --help` for more info.
 )
 
 
-@ws_app.command(short_help="Create a new phidata workspace in the current directory.")
+@ws_app.command(short_help="Create a new workspace in the current directory.")
 def init(
-    ws_name: str = typer.Option(None, "-ws", help="Name of the new workspace"),
+    ws_name: str = typer.Option(
+        None, "-ws", help="Name of the new workspace", show_default=False
+    ),
     template: str = typer.Option(
         "aws",
         "-t",
         "--template",
-        help="Choose a starter template which comes pre-populated with defaults. Available Options: {}".format(
-            ", ".join(WorkspaceStarterTemplate.values_list())
-        ),
+        help="Choose a starter template which comes pre-populated with defaults",
         show_default=True,
     ),
     print_debug_log: bool = typer.Option(
@@ -58,13 +57,12 @@ def init(
 ):
     """\b
     Creates a new workspace in the current directory using the selected starter template
-    [default: docker]
+    [default: aws]
 
     \b
     Examples:
-    $ phi ws init                -> Create a new workspace
-    $ phi ws init -ws data        -> Create a workspace named data using the default starter template (docker)
-    $ phi ws init -ws data -t aws -> Create a workspace named data using the `aws` starter template
+    $ phi ws init                 -> Create a new workspace
+    $ phi ws init -ws data        -> Create a workspace named data using the default starter template (aws)
     """
     from phiterm.workspace.ws_operator import (
         create_new_workspace,
@@ -94,7 +92,7 @@ def init(
     create_new_workspace(ws_name, _template)
 
 
-@ws_app.command(short_help="Setup a phidata workspace")
+@ws_app.command(short_help="Setup phidata workspace in the current directory")
 def setup(
     ws_name: str = typer.Option(None, "-ws", help="Name of the workspace to setup"),
     print_debug_log: bool = typer.Option(
@@ -105,14 +103,14 @@ def setup(
     ),
 ):
     """\b
-    Setup the current directory as a phidata workspace.
+    Setup a phidata workspace in the current directory.
     This command can be run from within the workspace directory
-        OR with a -ws flag to setup another workspace.
+        OR with a -ws flag to set-up another workspace.
 
     \b
     Examples:
-    $ `phi ws setup`         -> Setup the current directory as a phidata workspace
-    $ `phi ws setup -ws data` -> Setup the workspace named idata
+    $ `phi ws setup`          -> Setup the current directory as a phidata workspace
+    $ `phi ws setup -ws idata` -> Setup the workspace named idata
     """
     from pathlib import Path
     from phiterm.workspace.ws_operator import setup_workspace
@@ -213,7 +211,7 @@ def setup(
 
 
 @ws_app.command(
-    short_help="Deploy your active workspace",
+    short_help="Create resources for active workspace",
     options_metavar="\b",
 )
 def up(
@@ -293,6 +291,7 @@ def up(
     """
     from phiterm.conf.phi_conf import PhiConf, PhiWsData
     from phiterm.workspace.ws_operator import deploy_workspace
+    from phiterm.utils.dotenv import load_dotenv
 
     if print_debug_log:
         set_log_level_to_debug()
@@ -310,13 +309,15 @@ def up(
             print_available_workspaces(avl_ws)
         return
 
-    target_env_str: Optional[str] = None
-    target_config_str: Optional[str] = None
-    target_env: Optional[WorkspaceEnv] = None
+    # Load environment from .env
+    load_dotenv(workspace_root=active_ws_data.ws_root_path)
+
     target_config: Optional[WorkspaceConfigType] = None
+    target_config_str: Optional[str] = None
     target_name: Optional[str] = None
     target_type: Optional[str] = None
     target_app: Optional[str] = None
+    target_env: Optional[str] = None
 
     # derive env/name/type/config from ws_filter
     if ws_filter is not None:
@@ -328,7 +329,8 @@ def up(
         # logger.debug(f"Filters: {filters}")
         num_filters = len(filters)
         if num_filters >= 1:
-            target_env_str = filters[0]
+            if filters[0] != "":
+                target_env = filters[0]
         if num_filters >= 2:
             if filters[1] != "":
                 target_app = filters[1]
@@ -343,12 +345,6 @@ def up(
                 target_config_str = filters[4]
 
     # derive env/app/name/type/config from command options
-    if (
-        target_env_str is None
-        and env_filter is not None
-        and isinstance(env_filter, str)
-    ):
-        target_env_str = env_filter
     if (
         target_config_str is None
         and config_filter is not None
@@ -359,16 +355,15 @@ def up(
         target_name = name_filter
     if target_type is None and type_filter is not None and isinstance(type_filter, str):
         target_type = type_filter
-    if (
-        target_app is not None
-        and app_filter is not None
-        and isinstance(app_filter, str)
-    ):
+    if target_app is None and app_filter is not None and isinstance(app_filter, str):
         target_app = app_filter
+    if target_env is None and env_filter is not None and isinstance(env_filter, str):
+        target_env = env_filter
+    # logger.debug(f"app_filter: {type(app_filter)} | {app_filter}")
 
     # derive env/config/name/type from defaults
-    if target_env_str is None:
-        target_env_str = (
+    if target_env is None:
+        target_env = (
             active_ws_data.ws_config.default_env if active_ws_data.ws_config else None
         )
     if target_config_str is None:
@@ -377,18 +372,6 @@ def up(
             if active_ws_data.ws_config
             else None
         )
-
-    if target_env_str is not None:
-        if target_env_str.lower() not in WorkspaceEnv.values_list():
-            print_error(
-                f"{target_env_str} is not supported, please choose from: {WorkspaceEnv.values_list()}"
-            )
-            return
-        target_env = cast(
-            WorkspaceEnv,
-            WorkspaceEnv.from_str(target_env_str),
-        )
-
     if target_config_str is not None:
         if target_config_str.lower() not in WorkspaceConfigType.values_list():
             print_error(
@@ -406,6 +389,8 @@ def up(
     logger.debug(f"\ttarget_name  : {target_name}")
     logger.debug(f"\ttarget_type  : {target_type}")
     logger.debug(f"\ttarget_app   : {target_app}")
+    logger.debug(f"\tdry_run      : {dry_run}")
+    logger.debug(f"\tauto_confirm : {auto_confirm}")
     print_heading("Deploying workspace: {}\n".format(active_ws_data.ws_name))
     deploy_workspace(
         ws_data=active_ws_data,
@@ -419,7 +404,7 @@ def up(
     )
 
 
-@ws_app.command(short_help="Shutdown your active workspace - does not delete any data")
+@ws_app.command(short_help="Delete resources for active workspace.")
 def down(
     ws_filter: Optional[str] = typer.Argument(
         None,
@@ -463,6 +448,11 @@ def down(
         "--dry-run",
         help="Print which resources will be shut down and exit.",
     ),
+    auto_confirm: bool = typer.Option(
+        False,
+        "-y",
+        help="Skip the confirmation before deploying resources.",
+    ),
     print_debug_log: bool = typer.Option(
         False,
         "-d",
@@ -472,7 +462,7 @@ def down(
 ):
     """
     \b
-    Shuts down the active workspace but does not delete it.
+    Shuts down the active workspace.
 
     \b
     Examples:
@@ -480,6 +470,7 @@ def down(
     """
     from phiterm.conf.phi_conf import PhiConf, PhiWsData
     from phiterm.workspace.ws_operator import shutdown_workspace
+    from phiterm.utils.dotenv import load_dotenv
 
     if print_debug_log:
         set_log_level_to_debug()
@@ -497,13 +488,15 @@ def down(
             print_available_workspaces(avl_ws)
         return
 
-    target_env_str: Optional[str] = None
-    target_config_str: Optional[str] = None
-    target_env: Optional[WorkspaceEnv] = None
+    # Load environment from .env
+    load_dotenv(workspace_root=active_ws_data.ws_root_path)
+
     target_config: Optional[WorkspaceConfigType] = None
+    target_config_str: Optional[str] = None
     target_name: Optional[str] = None
     target_type: Optional[str] = None
     target_app: Optional[str] = None
+    target_env: Optional[str] = None
 
     # derive env/config/name/type from ws_filter
     if ws_filter is not None:
@@ -515,7 +508,8 @@ def down(
         # logger.debug(f"Filters: {filters}")
         num_filters = len(filters)
         if num_filters >= 1:
-            target_env_str = filters[0]
+            if filters[0] != "":
+                target_env = filters[0]
         if num_filters >= 2:
             if filters[1] != "":
                 target_app = filters[1]
@@ -530,12 +524,6 @@ def down(
                 target_config_str = filters[4]
 
     # derive env/app/name/type/config from command options
-    if (
-        target_env_str is None
-        and env_filter is not None
-        and isinstance(env_filter, str)
-    ):
-        target_env_str = env_filter
     if (
         target_config_str is None
         and config_filter is not None
@@ -546,16 +534,14 @@ def down(
         target_name = name_filter
     if target_type is None and type_filter is not None and isinstance(type_filter, str):
         target_type = type_filter
-    if (
-        target_app is not None
-        and app_filter is not None
-        and isinstance(app_filter, str)
-    ):
+    if target_app is None and app_filter is not None and isinstance(app_filter, str):
         target_app = app_filter
+    if target_env is None and env_filter is not None and isinstance(env_filter, str):
+        target_env = env_filter
 
     # derive env/config/name/type from defaults
-    if target_env_str is None:
-        target_env_str = (
+    if target_env is None:
+        target_env = (
             active_ws_data.ws_config.default_env if active_ws_data.ws_config else None
         )
     if target_config_str is None:
@@ -564,18 +550,6 @@ def down(
             if active_ws_data.ws_config
             else None
         )
-
-    if target_env_str is not None:
-        if target_env_str.lower() not in WorkspaceEnv.values_list():
-            print_error(
-                f"{target_env_str} is not supported, please choose from: {WorkspaceEnv.values_list()}"
-            )
-            return
-        target_env = cast(
-            WorkspaceEnv,
-            WorkspaceEnv.from_str(target_env_str),
-        )
-
     if target_config_str is not None:
         if target_config_str.lower() not in WorkspaceConfigType.values_list():
             print_error(
@@ -593,6 +567,8 @@ def down(
     logger.debug(f"\ttarget_name  : {target_name}")
     logger.debug(f"\ttarget_type  : {target_type}")
     logger.debug(f"\ttarget_app   : {target_app}")
+    logger.debug(f"\tdry_run      : {dry_run}")
+    logger.debug(f"\tauto_confirm : {auto_confirm}")
     print_heading("Shutdown workspace: {}\n".format(active_ws_data.ws_name))
     shutdown_workspace(
         ws_data=active_ws_data,
@@ -602,10 +578,11 @@ def down(
         target_type=target_type,
         target_app=target_app,
         dry_run=dry_run,
+        auto_confirm=auto_confirm,
     )
 
 
-@ws_app.command(short_help="Update your active workspace")
+@ws_app.command(short_help="Update resources for active workspace")
 def patch(
     ws_filter: Optional[str] = typer.Argument(
         None,
@@ -649,6 +626,11 @@ def patch(
         "--dry-run",
         help="Print which resources will be patched and exit.",
     ),
+    auto_confirm: bool = typer.Option(
+        False,
+        "-y",
+        help="Skip the confirmation before deploying resources.",
+    ),
     print_debug_log: bool = typer.Option(
         False,
         "-d",
@@ -678,6 +660,7 @@ def patch(
     """
     from phiterm.conf.phi_conf import PhiConf, PhiWsData
     from phiterm.workspace.ws_operator import patch_workspace
+    from phiterm.utils.dotenv import load_dotenv
 
     if print_debug_log:
         set_log_level_to_debug()
@@ -695,13 +678,15 @@ def patch(
             print_available_workspaces(avl_ws)
         return
 
-    target_env_str: Optional[str] = None
-    target_config_str: Optional[str] = None
-    target_env: Optional[WorkspaceEnv] = None
+    # Load environment from .env
+    load_dotenv(workspace_root=active_ws_data.ws_root_path)
+
     target_config: Optional[WorkspaceConfigType] = None
+    target_config_str: Optional[str] = None
     target_name: Optional[str] = None
     target_type: Optional[str] = None
     target_app: Optional[str] = None
+    target_env: Optional[str] = None
 
     # derive env/name/type/config from ws_filter
     if ws_filter is not None:
@@ -713,7 +698,8 @@ def patch(
         # logger.debug(f"Filters: {filters}")
         num_filters = len(filters)
         if num_filters >= 1:
-            target_env_str = filters[0]
+            if filters[0] != "":
+                target_env = filters[0]
         if num_filters >= 2:
             if filters[1] != "":
                 target_app = filters[1]
@@ -728,12 +714,6 @@ def patch(
                 target_config_str = filters[4]
 
     # derive env/app/name/type/config from command options
-    if (
-        target_env_str is None
-        and env_filter is not None
-        and isinstance(env_filter, str)
-    ):
-        target_env_str = env_filter
     if (
         target_config_str is None
         and config_filter is not None
@@ -744,30 +724,22 @@ def patch(
         target_name = name_filter
     if target_type is None and type_filter is not None and isinstance(type_filter, str):
         target_type = type_filter
-    if (
-        target_app is not None
-        and app_filter is not None
-        and isinstance(app_filter, str)
-    ):
+    if target_app is None and app_filter is not None and isinstance(app_filter, str):
         target_app = app_filter
+    if target_env is None and env_filter is not None and isinstance(env_filter, str):
+        target_env = env_filter
 
     # derive env/config/name/type from defaults
-    if target_env_str is None:
-        target_env_str = active_ws_data.ws_config.default_env
+    if target_env is None:
+        target_env = (
+            active_ws_data.ws_config.default_env if active_ws_data.ws_config else None
+        )
     if target_config_str is None:
-        target_config_str = active_ws_data.ws_config.default_config
-
-    if target_env_str is not None:
-        if target_env_str.lower() not in WorkspaceEnv.values_list():
-            print_error(
-                f"{target_env_str} is not supported, please choose from: {WorkspaceEnv.values_list()}"
-            )
-            return
-        target_env = cast(
-            WorkspaceEnv,
-            WorkspaceEnv.from_str(target_env_str),
+        target_config_str = (
+            active_ws_data.ws_config.default_config
+            if active_ws_data.ws_config
+            else None
         )
-
     if target_config_str is not None:
         if target_config_str.lower() not in WorkspaceConfigType.values_list():
             print_error(
@@ -785,6 +757,8 @@ def patch(
     logger.debug(f"\ttarget_name  : {target_name}")
     logger.debug(f"\ttarget_type  : {target_type}")
     logger.debug(f"\ttarget_app   : {target_app}")
+    logger.debug(f"\tdry_run      : {dry_run}")
+    logger.debug(f"\tauto_confirm : {auto_confirm}")
     print_heading("Patching workspace: {}\n".format(active_ws_data.ws_name))
     patch_workspace(
         ws_data=active_ws_data,
@@ -794,10 +768,11 @@ def patch(
         target_type=target_type,
         target_app=target_app,
         dry_run=dry_run,
+        auto_confirm=auto_confirm,
     )
 
 
-@ws_app.command(short_help="Restart your active workspace")
+@ws_app.command(short_help="Restart resources for active workspace")
 def restart(
     ws_filter: Optional[str] = typer.Argument(
         None,
@@ -860,6 +835,7 @@ def restart(
         type_filter=type_filter,
         app_filter=app_filter,
         dry_run=False,
+        auto_confirm=False,
         print_debug_log=print_debug_log,
     )
     print_info("Sleeping for 2 seconds..")
@@ -872,12 +848,13 @@ def restart(
         type_filter=type_filter,
         app_filter=app_filter,
         dry_run=False,
+        auto_confirm=False,
         print_debug_log=print_debug_log,
     )
     print_info("Workspace restarted!")
 
 
-@ws_app.command(short_help="Prints active workspace config")
+@ws_app.command(short_help="Prints active workspace config", hidden=True)
 def config(
     print_debug_log: bool = typer.Option(
         False,
@@ -894,6 +871,7 @@ def config(
     $ `phi ws config`         -> Print the active workspace config
     """
     from phiterm.conf.phi_conf import PhiConf, PhiWsData
+    from phiterm.utils.dotenv import load_dotenv
 
     if print_debug_log:
         set_log_level_to_debug()
@@ -911,4 +889,7 @@ def config(
             print_available_workspaces(avl_ws)
         return
 
+    # Load environment from .env
+    load_dotenv(workspace_root=active_ws_data.ws_root_path)
+
     active_ws_data.print_to_cli()
