@@ -44,9 +44,14 @@ def create_new_workspace(ws_name: str, template: WorkspaceStarterTemplate) -> bo
     NOTE: till the user runs `phi ws setup` the workspace is not registered with phidata
         and can only be used locally
     """
+    from shutil import copytree
     from phiterm.utils.filesystem import rmdir_recursive
     from phiterm.workspace.template_to_repo_map import template_to_repo_map
-    from phiterm.workspace.ws_utils import get_ws_config_file_path
+    from phiterm.workspace.ws_utils import (
+        get_ws_config_file_path,
+        get_ws_config_dir_path,
+    )
+    from phiterm.utils.git import GitCloneProgress
 
     current_dir: Path = Path(".").resolve()
 
@@ -119,6 +124,23 @@ def create_new_workspace(ws_name: str, template: WorkspaceStarterTemplate) -> bo
         ws_root_path=ws_root_path,
         ws_config_file_path=ws_config_file_path,
     )
+
+    try:
+        ws_config_dir_path: Path = get_ws_config_dir_path(ws_root_path)
+        ws_config_secrets_dir = ws_config_dir_path.joinpath("secrets").resolve()
+        ws_config_example_secrets_dir = ws_config_dir_path.joinpath(
+            "example_secrets"
+        ).resolve()
+
+        print_info(f"Creating {str(ws_config_secrets_dir)}")
+        copytree(
+            str(ws_config_example_secrets_dir),
+            str(ws_config_secrets_dir),
+        )
+    except Exception as e:
+        logger.warning(f"Could not create workspace/secrets: {e}")
+        logger.warning("Please create the folder manually")
+
     print_info(f"Your new workspace is available at {str(ws_root_path)}\n")
     return setup_workspace(ws_root_path=ws_root_path)
 
